@@ -1,38 +1,40 @@
 #ifndef NETDATA_LOG_H
 #define NETDATA_LOG_H 1
 
-#define D_WEB_BUFFER        0x00000001
-#define D_WEB_CLIENT        0x00000002
-#define D_LISTENER          0x00000004
-#define D_WEB_DATA          0x00000008
-#define D_OPTIONS           0x00000010
-#define D_PROCNETDEV_LOOP   0x00000020
-#define D_RRD_STATS         0x00000040
-#define D_WEB_CLIENT_ACCESS 0x00000080
-#define D_TC_LOOP           0x00000100
-#define D_DEFLATE           0x00000200
-#define D_CONFIG            0x00000400
-#define D_PLUGINSD          0x00000800
-#define D_CHILDS            0x00001000
-#define D_EXIT              0x00002000
-#define D_CHECKS            0x00004000
-#define D_NFACCT_LOOP       0x00008000
-#define D_PROCFILE          0x00010000
-#define D_RRD_CALLS         0x00020000
-#define D_DICTIONARY        0x00040000
-#define D_MEMORY            0x00080000
-#define D_CGROUP            0x00100000
-#define D_REGISTRY          0x00200000
-#define D_VARIABLES         0x00400000
-#define D_HEALTH            0x00800000
-#define D_CONNECT_TO        0x01000000
-#define D_SYSTEM            0x80000000
+#define D_WEB_BUFFER        0x0000000000000001
+#define D_WEB_CLIENT        0x0000000000000002
+#define D_LISTENER          0x0000000000000004
+#define D_WEB_DATA          0x0000000000000008
+#define D_OPTIONS           0x0000000000000010
+#define D_PROCNETDEV_LOOP   0x0000000000000020
+#define D_RRD_STATS         0x0000000000000040
+#define D_WEB_CLIENT_ACCESS 0x0000000000000080
+#define D_TC_LOOP           0x0000000000000100
+#define D_DEFLATE           0x0000000000000200
+#define D_CONFIG            0x0000000000000400
+#define D_PLUGINSD          0x0000000000000800
+#define D_CHILDS            0x0000000000001000
+#define D_EXIT              0x0000000000002000
+#define D_CHECKS            0x0000000000004000
+#define D_NFACCT_LOOP       0x0000000000008000
+#define D_PROCFILE          0x0000000000010000
+#define D_RRD_CALLS         0x0000000000020000
+#define D_DICTIONARY        0x0000000000040000
+#define D_MEMORY            0x0000000000080000
+#define D_CGROUP            0x0000000000100000
+#define D_REGISTRY          0x0000000000200000
+#define D_VARIABLES         0x0000000000400000
+#define D_HEALTH            0x0000000000800000
+#define D_CONNECT_TO        0x0000000001000000
+#define D_RRDHOST           0x0000000002000000
+#define D_LOCKS             0x0000000004000000
+#define D_SYSTEM            0x8000000000000000
 
 //#define DEBUG (D_WEB_CLIENT_ACCESS|D_LISTENER|D_RRD_STATS)
 //#define DEBUG 0xffffffff
 #define DEBUG (0)
 
-extern unsigned long long debug_flags;
+extern uint64_t debug_flags;
 
 extern const char *program_name;
 
